==> goods-center-api-2.7.10-20181024.112807-3-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/item/ItemQueryDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.item;

import java.io.Serializable;
import java.util.List;

/**
 * @author JunAngLiu
 * @Title: ItemQueryDto
 * @Description:
 * @date 2018/8/2314:32
 */
public class ItemQueryDto implements Serializable {


    private static final long serialVersionUID = 8225107399900296321L;

    private Boolean enable; // 启用停用
    private String type; // 商品类型，比如 QB，话费充值 等等
    private Long itemClassifyId; // 优惠券批次
    private String itemName; //商品名称
    private String operType; // 商品类型 移位运算 第0位：限时商品 第1位：限量商品 第2位：是否运营商品
    private List<Long> ids; //商品id集合
    private Integer offset; // 查询的起始值
    private Integer max; //查询数量



    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getItemClassifyId() {
        return itemClassifyId;
    }

    public void setItemClassifyId(Long itemClassifyId) {
        this.itemClassifyId = itemClassifyId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getOperType() {
        return operType;
    }

    public void setOperType(String operType) {
        this.operType = operType;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }
}

==> goods-center-api-2.9.77-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/item/ItemQueryDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.item;

import java.io.Serializable;
import java.util.List;

/**
 * @author JunAngLiu
 * @Title: ItemQueryDto
 * @Description:
 * @date 2018/8/2314:32
 */
public class ItemQueryDto implements Serializable {
    private static final long serialVersionUID = 8225107399900296321L;

    private Boolean enable; // 启用停用
    private String type; // 商品类型，比如 QB，话费充值 等等
    private List<String> typeList; // 商品类型列表，比如 QB，话费充值 等等
    private Long itemClassifyId; // 优惠券批次
    private String itemName; //商品名称
    private String operType; // 商品类型 移位运算 第0位：限时商品 第1位：限量商品 第2位：是否运营商品
    private List<Long> ids; //商品id集合
    private Integer offset; // 查询的起始值
    private Integer max; //查询数量
    //商品备注
    private String itemMemo;
    //列表类型, 活动商品：1， 兑吧商品：2， 京东商品：3
    private Integer listType;
    //version号
    private Long version;

    private Boolean hasStockWarn;

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getItemClassifyId() {
        return itemClassifyId;
    }

    public void setItemClassifyId(Long itemClassifyId) {
        this.itemClassifyId = itemClassifyId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getOperType() {
        return operType;
    }

    public void setOperType(String operType) {
        this.operType = operType;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public String getItemMemo() {
        return itemMemo;
    }

    public void setItemMemo(String itemMemo) {
        this.itemMemo = itemMemo;
    }

    public Integer getListType() {
        return listType;
    }

    public void setListType(Integer listType) {
        this.listType = listType;
    }

    public Long getVersion() {
        return version;
    }

    public void setVersion(Long version) {
        this.version = version;
    }

    public List<String> getTypeList() {
        return typeList;
    }

    public void setTypeList(List<String> typeList) {
        this.typeList = typeList;
    }

    public Boolean getHasStockWarn() {
        return hasStockWarn;
    }

    public void setHasStockWarn(Boolean hasStockWarn) {
        this.hasStockWarn = hasStockWarn;
    }
}
